### 2017 edits: At this point we have checked to see if we have replicated the results for the TAP 2016 paper
### Now, we analyze with the third condition

# select the data file (2017_poseperceptualstudydata_clean_ChildAdultDS_06:20.csv)
file.name<-file.choose()
# read the data from modified file into data frame
my.data<-read.csv(file.name)
# see preview to make sure data is read in expected format
head(my.data)
# check the field names
#[1] "ParticipantID"                                  [2]  "Action"
#[3] "Actor"                                          [4]  "ActorType"
#[5] "Does.this.motion.belong.to.a.Child.or.an.Adult."[6] "Confidence.score"
#[7] "correctness"                                    [8] "ResponseChild"
names(my.data)
# check the number of levels of each independent variable
# Are there 3 actor types?


# Are there 3 actor types?
#Correspond to Section 6, Paragraph 2, line 4
unique(my.data[,4])
# Are there 8 actors?
#Correspond to Section 6, Paragraph 2, line 6-8
unique(my.data[,3])
# Are there 6 action only?
#Correspond to Section 6, Paragraph 2, line 4-5
unique(my.data[,2])
# How many participants?
#Correspond to Section 6, Paragraph 1, line 6
unique(my.data[,1])
# this should be 24
length(unique(my.data[,1]))
# Check that you have the correct number of rows in the data frame
dim(my.data)
# this should be equal to 6(Actions)*9(Actors)*24(Participants) TIMES 8(columns)





#Were there any participants with accuracy <50% on Adult+Child ActorType (not counting DS)
participantID<-my.data[,1]
# formula x~y where x is the dependent variable, and y are the factors
numcorrect_by_participant<-aggregate(my.data[,7] ~ participantID, sum, data=my.data)
#overall percentage of correctness equal to the number of correct answer/36*100%
#correspond to section 7.1, paragraph 1, line 8-14
percentcorrect_by_participant<-numcorrect_by_participant
percentcorrect_by_participant[,2]<-(numcorrect_by_participant[,2]/36)*100

# Look at the distribution of correct responses
#correspond to figure 6
# Plot the accuracy by participant. Dotted line to represent chance level performance
plot(numcorrect_by_participant[,1],percentcorrect_by_participant[,2],xlab="Participant ID", ylab = "Percent Correct Responses",xlim = c(1,25), ylim = c(1,100))
abline(h=50,col=2, lty=1, lwd=1)

#Decision point: do we want to remove the participants that performed at or below chance?
#exclude outlier participant #18
#correspond to section 7.1, paragraph 1, line 16-18
my.data<-my.data[!(my.data$ParticipantID=="18" ),]


# Now, I want to compute the percent correct responses for child actor versus adult actor
childoradult<-my.data[,4]
# separate out the reponses to the child actor stimuli and the adult actor stimuli
my.data.childactoronly<-subset(my.data, my.data[,4] == "Child")
my.data.adultactoronly<-subset(my.data, my.data[,4] == "Adult")
# count the number of correct responses by each participant for all the child actor stimuli that she saw
# now we know the accuracy of identifying child actor stimuli by each participant
participantID<- my.data.childactoronly[,1]
numcorrect_childactoronly<-aggregate(my.data.childactoronly[,7]~participantID, sum, data=my.data.childactoronly)
# do the same for adult actor stimuli
participantID<- my.data.adultactoronly[,1]
numcorrect_adultactoronly<-aggregate(my.data.adultactoronly[,7]~participantID, sum, data=my.data.adultactoronly)
# merge the two data frames so that we have a 27x3 matrix, where each row represents a participant
# first column is participant ID
# second column is number of correct responses for child videos
# third column is number of correct responses for adult videos
numcorrect_childvsadult<-merge(numcorrect_childactoronly, numcorrect_adultactoronly, by="participantID")
# boxplot showing percentage of correctness of child actor and adult actor
#boxplot((numcorrect_childvsadult[,2:3]/18)*100, names = c("Child Actor", "Adult Actor"), ylab="Percent Correct Responses")
#title("Distribution of Correct Responses")
# plot individual histograms for adult actor and child actor
#correspond to figure 7
par(mfrow=c(1,2))
hist((numcorrect_childvsadult[,2]/18)*100, xlab = "Percent correct", main ="Child Actor", xlim = c(0,100) )
hist((numcorrect_childvsadult[,3]/18)*100, xlab = "Percent correct", main ="Adult Actor" , xlim = c(0,100))



# Shapiro test for percentage of correctness for adult and child videos to check if the distribution is normal.
#correspond to section 7.1, paragraph 2, line 1-4
#for child actor: W = 0.9754, p-value = 0.8151
shapiro.test(numcorrect_childvsadult[,2]/18*100)
#for adult actor: W = 0.97682, p-value = 0.8455
shapiro.test(numcorrect_childvsadult[,3]/18*100)



# t-test to see if the percentage of ResponseChild is above or below the 50% mark in each of the three conditions
#correspond to section 7.1, paragraph 2, line 8
# for adult actors, t = 7.0592, df = 22, p-value = 2.206e-07
t.test((numcorrect_childvsadult[,3]/18)*100, mu=50, alternative="greater")
#correspond to section 7.1, paragraph 2, line 10
# for child actors, t = 5.7664, df = 22, p-value = 4.213e-06
t.test((numcorrect_childvsadult[,2]/18)*100, mu=50, alternative="greater")
#correspond to section 7.1, paragraph 2, line 9
#Result: 14.06238
sd((numcorrect_childvsadult[,2]/18)*100)
#correspond to section 7.1, paragraph 2, line 7
#Result:12.4716
sd((numcorrect_childvsadult[,3]/18)*100)
#correspond to section 7.1, paragraph 2, line 9
#Result:66.90821
mean((numcorrect_childvsadult[,2]/18)*100)
#correspond to section 7.1, paragraph 2, line 7
#Result:68.35749
mean((numcorrect_childvsadult[,3]/18)*100)



# separate out the reponses to the child actor stimuli, the adult actor stimuli, and the dynamically scaled stimuli
my.data.childactoronly<-subset(my.data, my.data$ActorType == "Child")
my.data.adultactoronly<-subset(my.data, my.data$ActorType == "Adult")
my.data.DSactoronly<-subset(my.data, my.data$ActorType == "ds")
# check that all these subsets have 23*3*6 rows
dim(my.data.adultactoronly) # 414 x 8
dim(my.data.childactoronly) # 414 x 8
dim(my.data.DSactoronly) # 414 x 8
# count the number of ResponseChild by each participant for all the child actor stimuli that she saw
# then we know the accuracy of identifying child actor stimuli by each participant
participantID<- my.data.childactoronly$ParticipantID
numResponseChild_childactoronly<-aggregate(my.data.childactoronly$ResponseChild~participantID, sum, data=my.data.childactoronly)
# do the same for adult actor stimuli
participantID<- my.data.adultactoronly$ParticipantID # this is redundant, but we're putting it here for completeness
numResponseChild_adultactoronly<-aggregate(my.data.adultactoronly$ResponseChild~participantID, sum, data=my.data.adultactoronly)
# do the same for DS actor stimuli
participantID<- my.data.DSactoronly$ParticipantID # this is redundant, but we're putting it here for completeness
numResponseChild_DSactoronly<-aggregate(my.data.DSactoronly$ResponseChild~participantID, sum, data=my.data.DSactoronly)






#Shapiro test for number of child responses for all three levels.
#Reported in section 7.2, paragraph 1, line 12-13
# For child actor, W = 0.9754, p-value = 0.8151
shapiro.test(numResponseChild_childactoronly[,2])
# For adult actor,W = 0.97682, p-value = 0.8455
shapiro.test(numResponseChild_adultactoronly[,2])
# For ds actor,W = 0.93777, p-value = 0.1609
shapiro.test(numResponseChild_DSactoronly[,2])




#stack the number of child response for adult, child, ds actor together in one table
numResponseChild_childvsadultvsDS<-merge(numResponseChild_childactoronly, numResponseChild_adultactoronly, by="participantID")
numResponseChild_childvsadultvsDS<-merge(numResponseChild_childvsadultvsDS, numResponseChild_DSactoronly, by="participantID")
dim(numResponseChild_childvsadultvsDS) # 23x4




# visualize percent ResponseChild in a boxplot
#correspond to figure 8
boxplot((numResponseChild_childvsadultvsDS[,2:4]/18)*100, names = c("Child Actor", "Adult Actor", "Dynamically Scaled"), ylab="Percent Child Responses",cex.axis=1.3,cex.lab=1.3,cex.main=1.3)
title("Distribution of Responses")


# Data preparation for mean and sd and also ANOVA
# analysis of variances (ANOVA) to see if difference in means is significant
# within subjects => repeated measures ANOVA
# First, we need to reorganize the within subjects data to be "stacked"

# stackedraw<-stack(numResponseChild_childvsadultvsDS[,2:4])
# numconditions = 3
# numsubjects = 23
# subj=factor(rep(1:numsubjects, numconditions))
# cond1= rep("Child",numsubjects)
# cond2= rep("Adult",numsubjects)
# cond3= rep("DynamicallyScaled",numsubjects)
# actortype=factor(c(cond1,cond2,cond3))
# # stacked_numResponseChild_childvsadultvsDS is the stacked data frame
# stacked_numResponseChild_childvsadultvsDS = data.frame(numResponseChild=stackedraw[,1], subj, actortype)
# names(stacked_numResponseChild_childvsadultvsDS) # check column headers
# dim(stacked_numResponseChild_childvsadultvsDS) # check dimensions (23*3 rows, 3 columns)



library(nlme)
require(multcomp)



ParticipantID <- my.data[,1]
Action <- my.data[,2]
ActorType <- my.data[,4]
ResponseChild <- my.data[,5]
# create table that contain PID and ActorType
stacked_numResponseChildActionTypeActorType <- aggregate(ResponseChild ~ ParticipantID + ActorType+Action, sum, data = my.data)
# create table that contain PID and Action
stacked_numResponseChildAction <- aggregate(ResponseChild ~ ParticipantID + Action, sum, data = my.data)
stacked_numResponseChildActorType <- aggregate(ResponseChild ~  ParticipantID + ActorType, sum, data = my.data)
stacked_numResponseChildActionTypeActorType_sum <- aggregate(ResponseChild ~   Action+ActorType, sum, data = my.data)


#This correspond to the paper secion 7.3, line 13
# Action ActorType ResponseChild
# 4  runfast     Adult            24
# 10 runfast     Child            56
# 16 runfast        ds            30
stacked_numResponseChildMotionTypeActorType_sum_runfast<-subset(stacked_numResponseChildActionTypeActorType_sum,Action=="runfast")





# This correspond to paper the last third sentences

# Action Actor ResponseChild
#  jumphigh   290     0.7391304
#  jumphigh   337     0.6086957
#  jumphigh   644     0.3913043
#  jumphigh   723     0.5217391

stacked_numResponseChildMotionTypeActor <- aggregate(ResponseChild ~   Action+Actor, sum, data = my.data)
stacked_numResponseChildMotionTypeActor_jumphigh<-subset(stacked_numResponseChildMotionTypeActor,Action=="jumphigh")
stacked_numResponseChildMotionTypeActor_jumphigh$ResponseChild<-stacked_numResponseChildMotionTypeActor_jumphigh$ResponseChild/23



#Compute the mean and standard deviation for overall number of child responses respect to actor type
#Reported in Figure 9(a)
# actortype          numResponseChild
# Adult              5.695652
# Child              12.043478
# DynamicallyScaled  7.347826
#numResponseChildmean <- aggregate( numResponseChild ~ actortype, mean, data=stacked_numResponseChild_childvsadultvsDS)
numResponseChildmean <- aggregate( ResponseChild ~ ActorType, mean, data=stacked_numResponseChildActorType)
#Reported in Figure 9(a)
# actortype                 numResponseChild
# Adult                     2.244889
# Child                     2.531228
# DynamicallyScaled         2.166033
numResponseChildstd <- aggregate( ResponseChild ~ ActorType, sd, data=stacked_numResponseChildActorType)
#Stack the mean and sd in one table
numResponseChildboth<-merge(numResponseChildmean,numResponseChildstd,by='ActorType')
names(numResponseChildboth)[2] <- "NumberOfResponsesAsChild"
names(numResponseChildboth)[1] <- "ActorType"




#Compute the mean and standard deviation for overall number of child responses respect to action
#Reported in Figure 9(b)
# Action ResponseChild
# 1 flylikeabird      4.260870
# 2     jumphigh      4.565217
# 3 jumpingjacks      3.217391
# 4      runfast      4.782609
# 5         walk      3.956522
# 6         wave      4.304348
numResponseChild_ActionOnly_mean <- aggregate(ResponseChild  ~ Action, mean, data=stacked_numResponseChildAction)
#Reported in Figure 9(b)
# Action ResponseChild
# 1 flylikeabird      1.763710
# 2     jumphigh      1.561645
# 3 jumpingjacks      1.536126
# 4      runfast      1.536126
# 5         walk      2.120854
# 6         wave      2.098371
numResponseChild_ActionOnly_std <- aggregate( ResponseChild  ~ Action, sd, data=stacked_numResponseChildAction)
#Stack the mean and sd in one table
numResponseChild_ActionOnly_both<-merge(numResponseChild_ActionOnly_mean,numResponseChild_ActionOnly_std,by=c('Action'))





#Two-way anova on number of child responses respect to action and actor type
#Result:
#numDF denDF  F-value p-value
# numDF denDF  F-value p-value
# (Intercept)     1   384 851.8769  <.0001
# ActorType       2   384  57.5662  <.0001
# Action          5   384   3.2061  0.0075
#Reported in section 7.2, paragraph 2, line 5
amoverall_2way <- lme(ResponseChild~ActorType+Action, random =  ~1|ParticipantID, data = stacked_numResponseChildActionTypeActorType)
anova(amoverall_2way)

#Reported in section 7.2, paragraph 2, line 6-8
#perform Tukdy HSD test
#Estimate Std. Error z value Pr(>|z|)    
#Estimate Std. Error z value Pr(>|z|)    
#Child - Adult == 0   1.0580     0.1023  10.341   <0.001 ***
#  ds - Adult == 0      0.2754     0.1023   2.692   0.0195 *  
#  ds - Child == 0     -0.7826     0.1023  -7.650   <0.001 ***
summary(glht(amoverall_2way,linfct=mcp(ActorType ="Tukey")))

# 
# Linear Hypotheses:
#   Estimate Std. Error z value Pr(>|z|)   
# jumphigh - flylikeabird == 0      0.10145    0.14468   0.701  0.98185   
# jumpingjacks - flylikeabird == 0 -0.34783    0.14468  -2.404  0.15466   
# runfast - flylikeabird == 0       0.17391    0.14468   1.202  0.83610   
# walk - flylikeabird == 0         -0.10145    0.14468  -0.701  0.98186   
# wave - flylikeabird == 0          0.01449    0.14468   0.100  1.00000   
# jumpingjacks - jumphigh == 0     -0.44928    0.14468  -3.105  0.02335 * 
#   runfast - jumphigh == 0           0.07246    0.14468   0.501  0.99616   
# walk - jumphigh == 0             -0.20290    0.14468  -1.402  0.72570   
# wave - jumphigh == 0             -0.08696    0.14468  -0.601  0.99099   
# runfast - jumpingjacks == 0       0.52174    0.14468   3.606  0.00418 **
#   walk - jumpingjacks == 0          0.24638    0.14468   1.703  0.52990   
# wave - jumpingjacks == 0          0.36232    0.14468   2.504  0.12283   
# walk - runfast == 0              -0.27536    0.14468  -1.903  0.40003   
# wave - runfast == 0              -0.15942    0.14468  -1.102  0.88079   
# wave - walk == 0                  0.11594    0.14468   0.801  0.96736  

summary(glht(amoverall_2way,linfct=mcp(Action ="Tukey")))

#Compute interaction effect cross action and actor type
#reported in section 8, paragraph 4, line 1
#stacked_numResponseChildMotionTypeActorType$IN <- interaction(stacked_numResponseChildMotionTypeActorType$ActorType, stacked_numResponseChildMotionTypeActorType$Action)
#mod2 <- lme(ResponseChild ~  IN, data=stacked_numResponseChildMotionTypeActorType, random=~1|ParticipantID)
#summary(glht(mod2, linfct=mcp(IN="Tukey")))




#install required package for plot
install.packages("ggplot2")
library(ggplot2)
install.packages("ggsignif")
library(ggsignif)

numsubjects=23
#correspond to figure 10
#plot the bar chart for number of child response with respect to actor type
dodge <- position_dodge(width = 0.9)
dat <- data.frame(ActorType = c( "Child","DS","Adult"), NumberOfResponsesAsChild = c(12.043478,7.347826,5.695652))
dat$ActorType <- factor(dat$ActorType, levels=c("Child","DS","Adult"))
limits <- aes(ymax = numResponseChildboth[c(2,3,1),2] + numResponseChildboth[c(2,3,1),3]/sqrt(numsubjects), ymin = numResponseChildboth[c(2,3,1),2] - numResponseChildboth[c(2,3,1),3]/sqrt(numsubjects))
p <-    ggplot(dat, aes(ActorType, NumberOfResponsesAsChild))+theme_bw() + theme(panel.grid = element_blank())  + coord_cartesian(ylim = c(0, 17))  +scale_fill_manual(values = c("grey80", "grey60","grey40")) +  geom_bar(aes(fill = ActorType), stat="identity", position="dodge", width=.5)+theme(legend.position="none") +theme(axis.title.x =element_text(size=15), axis.title.y=element_text(size=15),axis.text.x =element_text(size=14),axis.text.y =element_text(size=14))+geom_errorbar(limits, position = dodge, width = 0.25)
label.df <- data.frame(ActorType = c(1.5,1.5,1.5,2.5),NumberOfResponsesAsChild = c(15.3,15.6,15.9,15.3))
#plot the arc between two different groups
r <- 0.4
t <- seq(0, 180, by = 1) * pi / 180
x <- r * cos(t)
y <- r*5 * sin(t)
arc.df <- data.frame(ActorType = x, NumberOfResponsesAsChild = y)
p2 <-p + geom_text(data = label.df, label = "*") +geom_line(data = arc.df, aes(ActorType+1.5, NumberOfResponsesAsChild+13), lty = 2) +geom_line(data = arc.df, aes(ActorType+2.5, NumberOfResponsesAsChild+13), lty = 2)
r <- 1
x <- r * cos(t)
y <- r*4 * sin(t)
y[20:162] <- y[20] # Flattens the arc,
arc2.df <- data.frame(ActorType = x, NumberOfResponsesAsChild = y)
p2 + geom_line(data = arc2.df, aes(ActorType+2, NumberOfResponsesAsChild+15.3), lty = 2) +
  geom_text(x = 2, y = 17, label = "***")



#correspond to figure 11
#plot the bar chart of number of child response with respect to action
dat <- data.frame(Action = c("Fly like\n a bird", "Jump high", "Jumping\n jacks","Run fast","Walk","Wave"), NumberOfResponsesAsChild = c(3*1.420290,3*1.521739,3*1.072464,3*1.594203,3*1.318841,3*1.434783))
limits_Action <- aes(ymax = numResponseChild_ActionOnly_both[,2] + numResponseChild_ActionOnly_both[,3]/sqrt(numsubjects),ymin = numResponseChild_ActionOnly_both[,2]- numResponseChild_ActionOnly_both[,3]/sqrt(numsubjects))
p <-    ggplot(dat, aes(Action, NumberOfResponsesAsChild))+theme_bw() +theme(axis.title.x =element_text(size=15), axis.title.y=element_text(size=15),axis.text.x =element_text(size=14),axis.text.y =element_text(size=14))+ theme(panel.grid = element_blank()) + coord_cartesian(ylim = c(0, 6))  + scale_fill_manual(values = c("grey80", "grey70","grey60","grey50","grey40","grey30")) +  geom_bar(aes(fill = Action), stat="identity", position="dodge", width=.5)+theme(legend.position="none")+geom_errorbar(limits_Action, position = dodge, width = 0.25)
label.df <- data.frame(Action = c(2.5,3.5,3.5),NumberOfResponsesAsChild = c(5.3,5.3,5.45))
#plot the arc between two different groups
r <- 0.35
t <- seq(0, 180, by = 1) * pi / 180
x <- r * cos(t)
y <- r*0.5 * sin(t)
arc.df <- data.frame(Action = x, NumberOfResponsesAsChild = y)
p2 <-p + geom_text(data = label.df, label = "*") +geom_line(data = arc.df, aes(Action+3.5, NumberOfResponsesAsChild+5), lty = 2) +geom_line(data = arc.df, aes(Action+2.5, NumberOfResponsesAsChild+5), lty = 2)
r <- 1
x <- r * cos(t)
y <- r*4 * sin(t)
y[20:162] <- y[20] # Flattens the arc,
arc2.df <- data.frame(ActorType = x, NumberOfResponsesAsChild = y)
p2 + geom_line(data = arc2.df, aes(ActorType+2, NumberOfResponsesAsChild+15.3), lty = 2) +
  geom_text(x = 2, y = 17, label = "*")






#correspond to figure 12
#plot the bar chart of number of child response with respect to action and actor type
#Compute the mean and standard deviation for overall number of child responses respect to actor type and action
numResponseChild_Action_mean <- aggregate( ResponseChild ~ Action+ActorType, mean, data=stacked_numResponseChildActionTypeActorType)
numResponseChild_Action_std <- aggregate( ResponseChild ~ Action+ActorType, sd, data=stacked_numResponseChildActionTypeActorType)
#Stack the mean and sd in one table
numResponseChild_Action_both<-merge(numResponseChild_Action_mean,numResponseChild_Action_std,by=c('Action','ActorType'))
names(numResponseChild_Action_both)[3] <- "NumberOfResponsesAsChild"
numResponseChild_Action_both$ActorType <- factor(numResponseChild_Action_both$ActorType, levels=c("Child", "ds", "Adult"))
limits_ActionActor <- aes(ymax = numResponseChild_Action_both[,3] + numResponseChild_Action_both[,4]/sqrt(numsubjects), ymin = numResponseChild_Action_both[,3] - numResponseChild_Action_both[,4]/sqrt(numsubjects))
ggplot(numResponseChild_Action_both, aes(x =Action, y = NumberOfResponsesAsChild, fill = ActorType)) + geom_bar(stat="identity", position = "dodge") +
  scale_fill_brewer(palette = "Set1")+geom_errorbar(limits_ActionActor, position = dodge, width = 0.25)+ theme_bw()+scale_x_discrete(labels=c("Fly like\n a bird", "Jump high", "Jumping\n jacks","Run fast","Walk","Wave"))+scale_fill_manual(values = c("grey80","grey60", "grey40"),labels=c( "Child","DS","Adult")) +theme(axis.title.x =element_text(size=15), axis.title.y=element_text(size=15),axis.text.x =element_text(size=14),axis.text.y =element_text(size=14),legend.text =element_text(size=14) ,legend.title = element_text(size=14))
scale_x_discrete(labels=c("Fly like\n a bird", "Jump high", "Jumping\n jacks","Run fast","Walk","Wave"))



#reported in section 8, paragraph 2, line 11
#one way anova and tukey test for confidence score respect to actor type

# numDF denDF   F-value p-value
# (Intercept)     1  1217 1147.6859  <.0001
# ActorType       2  1217    0.5189  0.5953
amcon <- lme(Confidence.score ~ ActorType, random = ~1|ParticipantID, data=my.data)
anova(amcon)
#Estimate Std. Error z value Pr(>|z|)
#Child - Adult == 0  0.002415   0.072594   0.033    0.999
#ds - Adult == 0    -0.062802   0.072594  -0.865    0.662
#ds - Child == 0    -0.065217   0.072594  -0.898    0.641
#(Adjusted p values reported -- single-step method)
summary(glht(amcon,linfct=mcp(ActorType ="Tukey")))

# # #------------------------------------------------------------------------------------------------------------------------------------------------------

