%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Date Created: 02/19/2016
%Date Revised: 04/15/2016
%Revision made by: Aishat Aloba
%This function takes as input the name of a data file representing a 
%participant's gesture, the data file itself, and a list that tells which
%joints is selected.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function  funcplot(fname,joints,hc)

        dirname = strsplit(char(fname),'_');
        dirname = dirname(1);
          
        %Make the directory if it does not exist
         if exist(char(dirname)) == 0
            mkdir(char(dirname));
         end
    
       % Set up the output video file. For the example it should be
       % POSE-p290/POSE-p290_58-Do-two-jumping-jacks-1455357418660.avi
        name = strcat(dirname,'/',fname,'.avi');
        %name = strcat(fname,'.avi');
        writerObj = VideoWriter(char(name)); % Name it.
        writerObj.FrameRate = 30; % How many frames per second.
        open(writerObj);
        
        ph =  figure;
        %customize the figure created by hiding the axes and making the 
        %background black
        set(gca,'visible','off');
        set(gcf,'color','black');
        
        %The figures created in matlab are being cut off hence center the
        % data points so that the origin is in line with that of MATLAB
        yoffset = calculateOffset(joints);
        
        %subtract the mean from the y dimension of the joint data
        joints{:,2:3:end} = joints{:,2:3:end} - yoffset;
        
        %customize figure to show menu, allow zoom and 3D rotation.
        hCMZ = uicontextmenu;
        hZMenu = uimenu('Parent',hCMZ,'Label','Switch to pan','Callback','pan(gcbf,''on'')');
        hZoom = zoom(gcf);
        hZoom.UIContextMenu = hCMZ;
        zoom('on');
        rotate3d('on');
        
        %Account for size differences between Children and Adults by
        %scaling the axes to zoom in the figure.
        
        %get the highest point which is the head joint in the first frame. 
        %For the example, this should be 0.4907m
        maxY = max(joints.HeadY(1));
        
        %get the lowest point which is the minimum of the left
        %or right foot joint in the first frame.For the example,
        %this should be  -0.6537m
        minY = min([joints.FootRightY(1);joints.FootLeftY(1)]);

        
        %calculate the height of the participant. For the example, the
        %height should be  1.1443m
        height = maxY-  minY;
        
        %Use the values calculated to scale the x and y axis.
        %The height is used to add enough padding above and below to
        %account for gestures like jump where a participant may have
        %jumped too high.
        axis equal;
        axis([-1,1,minY - (height/8),maxY + (height/2)]);
        DELAY = 0.05;
        
        %Plot the data for the point light displays by checking if a joint
        %was selected.
        for i = 1:numel(joints.HipCenterX)
            hold on;
            if hc(1) == 1
                plot3(joints.HipCenterX(i),joints.HipCenterY(i),joints.HipCenterZ(i), 'o','MarkerEdgeColor','w','MarkerFaceColor',[1 1 1],'MarkerSize',3);
                
            end
            if hc(2) == 1
                plot3(joints.SpineX(i),joints.SpineY(i),joints.SpineZ(i),'o','MarkerEdgeColor','w','MarkerFaceColor',[1 1 1],'MarkerSize',3);
            end
            if hc(3) == 1
                plot3(joints.ShoulderCenterX(i),joints.ShoulderCenterY(i),joints.ShoulderCenterZ(i),'o','MarkerEdgeColor','w','MarkerFaceColor',[1 1 1],'MarkerSize',3);
            
            end
            if hc(4) == 1
                plot3(joints.HeadX(i),joints.HeadY(i),joints.HeadZ(i),'o','MarkerEdgeColor','w','MarkerFaceColor',[1 1 1],'MarkerSize',3);
            end
            if hc(5) == 1
                plot3(joints.ShoulderLeftX(i),joints.ShoulderLeftY(i),joints.ShoulderLeftZ(i),'o','MarkerEdgeColor','w','MarkerFaceColor',[1 1 1],'MarkerSize',3);
            end
            if hc(6) == 1
                plot3(joints.ElbowLeftX(i),joints.ElbowLeftY(i),joints.ElbowLeftZ(i),'o','MarkerEdgeColor','w','MarkerFaceColor',[1 1 1],'MarkerSize',3);
            end
            if hc(7) == 1
                plot3(joints.WristLeftX(i),joints.WristLeftY(i),joints.WristLeftZ(i),'o','MarkerEdgeColor','w','MarkerFaceColor',[1 1 1],'MarkerSize',3);
            end
            if hc(8) == 1
                plot3(joints.HandLeftX(i),joints.HandLeftY(i),joints.HandLeftZ(i),'o','MarkerEdgeColor','w','MarkerFaceColor',[1 1 1],'MarkerSize',3);
            end
            if hc(9) == 1
                plot3(joints.ShoulderRightX(i),joints.ShoulderRightY(i),joints.ShoulderRightZ(i),'o','MarkerEdgeColor','w','MarkerFaceColor',[1 1 1],'MarkerSize',3);
            end
            if hc(10) == 1
                plot3(joints.ElbowRightX(i),joints.ElbowRightY(i),joints.ElbowRightZ(i),'o','MarkerEdgeColor','w','MarkerFaceColor',[1 1 1],'MarkerSize',3);
            end
            if hc(11) == 1
                plot3(joints.WristRightX(i),joints.WristRightY(i),joints.WristRightZ(i), 'o','MarkerEdgeColor','w','MarkerFaceColor',[1 1 1],'MarkerSize',3);
            end
            if hc(12) == 1
                plot3(joints.HandRightX(i),joints.HandRightY(i),joints.HandRightZ(i), 'o','MarkerEdgeColor','w','MarkerFaceColor',[1 1 1],'MarkerSize',3);
            end
            if hc(13) == 1
                plot3(joints.HipLeftX(i),joints.HipLeftY(i),joints.HipLeftZ(i),'o','MarkerEdgeColor','w','MarkerFaceColor',[1 1 1],'MarkerSize',3);
            end
            if hc(14) == 1
                plot3(joints.KneeLeftX(i),joints.KneeLeftY(i),joints.KneeLeftZ(i),'o','MarkerEdgeColor','w','MarkerFaceColor',[1 1 1],'MarkerSize',3);
            end
            if hc(15) == 1
                plot3(joints.AnkleLeftX(i),joints.AnkleLeftY(i),joints.AnkleLeftZ(i),'o','MarkerEdgeColor','w','MarkerFaceColor',[1 1 1],'MarkerSize',3);
            end
            if hc(16) == 1
                plot3(joints.FootLeftX(i),joints.FootLeftY(i),joints.FootLeftZ(i),'o','MarkerEdgeColor','w','MarkerFaceColor',[1 1 1],'MarkerSize',3);
            end
            if hc(17) == 1
                plot3(joints.HipRightX(i),joints.HipRightY(i),joints.HipRightZ(i),'o','MarkerEdgeColor','w','MarkerFaceColor',[1 1 1],'MarkerSize',3);
            end
            if hc(18) == 1
                plot3(joints.KneeRightX(i),joints.KneeRightY(i),joints.KneeRightZ(i),'o','MarkerEdgeColor','w','MarkerFaceColor',[1 1 1],'MarkerSize',3);
            end
            if hc(19) == 1
                plot3(joints.AnkleRightX(i),joints.AnkleRightY(i),joints.AnkleRightZ(i),'o','MarkerEdgeColor','w','MarkerFaceColor',[1 1 1],'MarkerSize',3);
            end
            if hc(20) == 1
                plot3(joints.FootRightX(i),joints.FootRightY(i),joints.FootRightZ(i),'o','MarkerEdgeColor','w','MarkerFaceColor',[1 1 1],'MarkerSize',3);
            end
            
            
            
            pause(DELAY);
            
            %write frame to video
            frame = getframe(gcf); % 'gcf' can handle if you zoom in to take a movie.
            writeVideo(writerObj, frame);
            items = get(gca, 'Children');
            delete(items);
        end;
        hold off
        close(writerObj);
        
        %save the figure
        figname = strcat(fname,'.fig');
        figname = char(figname)
        savefig(ph,figname);
        close(ph);
       
    end