%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Date Created: 02/19/2016
%Date Revised: 04/15/2016
%Revision made by: Aishat Aloba
%How to run: To run this code, you need a local version of MATLAB installed
% or access to the RFS
% This function prompts users to specify the type of stimuli
% to be created. n for normal stimuli, and r for random stimuli.
% The function also allows you to select a data file or directory of files to
% be chosen and creates a scaled version point-light displays 
%for each of the stimuli chosen. Example - Select the data for 
%participant 106 - Jumping jacks located at
%/cise/research/init/proj/kidspose/studies/Pose-Perception/Analysis/
%Stimuli_Creation/Pose-Transformed/POSE-p290_58-Do-two-jumping-jacks-1455357418660.csv
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function myGUI()
%create array that stores users choices
clc;
clear;
global hc;
global state;
global stimuliType
hc = zeros(1,20); %array that keeps track of the joints selected

prompt = 'Enter the type of stimuli video you want to create (n for normal and r for random): ';
str = input(prompt,'s');
stimuliType = str;
%Get the file(s) from the directory
 DELAY = 0.80;

  [filename,path] = uigetfile('*.csv','Select joints','Multiselect','on');
  
  if ischar(filename)
      filename = {filename};
  end


%Process each of the files selected
for f = 1: length(filename)
  %Get the filename from the file selected to use in the output file
  fname = strsplit(char(filename(f)),'.');
  fname = fname(1);
  %get the full file
  tempfile = fullfile(path,char(filename(f)));

  %read the data from the file
  joints = readtable(tempfile);
  
  
  %create gui to customize which joints of the participant is to be seen
  if f == 1
    % Create figure
    h.f = figure('units','pixels','position',[500,500,450,350],...
        'toolbar','none','menu','none');
     %create radio buttons
    bg = uibuttongroup('Visible','off',...
                  'Position',[.6 0 .5 1],...
                  'SelectionChangedFcn',@bselection);
              
     % Create three radio buttons in the button group.
    h.r(1) = uicontrol(bg,'Style',...
                  'radiobutton',...
                  'String','Option 1',...
                  'Position',[10 280 100 30],...
                  'HandleVisibility','off');
              
    h.r(2) = uicontrol(bg,'Style','radiobutton',...
                  'String','Option 2',...
                  'Position',[10 250 100 30],...
                  'HandleVisibility','off');

   h.r(3) = uicontrol(bg,'Style','radiobutton',...
                  'String','Option 3',...
                  'Position',[10 220 100 30],...
                  'HandleVisibility','off');
              
   % Make the uibuttongroup visible after creating child objects. 
    bg.Visible = 'on';
    bg.BorderType = 'none';
              
    % Create yes/no checkboxes
    h.c(1) = uicontrol('style','checkbox','units','pixels',...
        'position',[10,30,100,15],'string','HipCenter');
    h.c(2) = uicontrol('style','checkbox','units','pixels',...
        'position',[110,30,100,15],'string','Spine');
    h.c(3) = uicontrol('style','checkbox','units','pixels',...
        'position',[210,30,100,15],'string','ShoulderCenter');
    h.c(4) = uicontrol('style','checkbox','units','pixels',...
        'position',[310,30,100,15],'string','Hnead');
    h.c(5) = uicontrol('style','checkbox','units','pixels',...
        'position',[10,60,100,15],'string','ShoulderLeft');
    h.c(6) = uicontrol('style','checkbox','units','pixels',...
        'position',[110,60,100,15],'string','ElbowLeft');
    h.c(7) = uicontrol('style','checkbox','units','pixels',...
        'position',[210,60,100,15],'string','WristLeft');
    h.c(8) = uicontrol('style','checkbox','units','pixels',...
        'position',[310,60,100,15],'string','HandLeft');
    h.c(9) = uicontrol('style','checkbox','units','pixels',...
        'position',[10,90,100,15],'string','ShoulderRight');
    h.c(10) = uicontrol('style','checkbox','units','pixels',...
        'position',[110,90,100,15],'string','ElbowRight');
    h.c(11) = uicontrol('style','checkbox','units','pixels',...
        'position',[210,90,100,15],'string','WristRight');
    h.c(12) = uicontrol('style','checkbox','units','pixels',...
        'position',[310,90,100,15],'string','HandRight');
    h.c(13) = uicontrol('style','checkbox','units','pixels',...
        'position',[10,120,100,15],'string','HipLeft');
    h.c(14) = uicontrol('style','checkbox','units','pixels',...
        'position',[110,120,100,15],'string','KneeLeft');
    h.c(15) = uicontrol('style','checkbox','units','pixels',...
        'position',[210,120,100,15],'string','AnkleLeft');
    h.c(16) = uicontrol('style','checkbox','units','pixels',...
        'position',[310,120,100,15],'string','FootLeft');
    h.c(17) = uicontrol('style','checkbox','units','pixels',...
        'position',[10,150,100,15],'string','HipRight');
    h.c(18) = uicontrol('style','checkbox','units','pixels',...
        'position',[110,150,100,15],'string','KneeRight');
    h.c(19) = uicontrol('style','checkbox','units','pixels',...
        'position',[210,150,100,15],'string','AnkleRight');
    h.c(20) = uicontrol('style','checkbox','units','pixels',...
        'position',[310,150,100,15],'string','FootRight');

   

    % Create OK pushbutton
    h.p(1) = uicontrol('style','pushbutton','units','pixels',...
        'position',[40,5,70,20],'string','OK',...
        'callback',@p_call);
    
    %allow users to select all the joints
    h.p(2) = uicontrol('style','pushbutton','units','pixels',...
        'position',[150,280,70,20],'string','Select All',...
        'callback',@selectAll);
   
    %clear all selections
    h.p(3) = uicontrol('style','pushbutton','units','pixels',...
        'position',[150,250,70,20],'string','Clear All',...
        'callback',@clearAll);
      
  %delays the figure showing the point light displays from being loaded 
  %automatically until the joints have been selected
  uiwait(gcf);
  %show the menu only once for multiple files selected.
  elseif f ~= 1
       
       loadState();
       if(strcmp(stimuliType,'n')==1)
            funcplot(fname,joints,hc);
       elseif(strcmp(stimuliType,'r')==1)
           funcplotRandom(fname,joints,hc);
       else
           error('The stimuli type must be \"n\" or \"r\"');
       end
  end
  
   disp(strcat('finished',fname));

end
 
 %save the state of the function in a menu.mat file so that we know what 
 %joints was selected and this can be used for subsequent files selected.
 function saveState(state)
       for val = 1:20
           fieldname = strcat('a',num2str(val));
           state.(fieldname) = get(h.c(val),'value');
       end
       
      save('menu.mat','state');
    
 end

%load the menu state from data to be used for subsequent files
    function loadState()
        dataname = 'menu.mat';
        if exist(dataname)
            load(dataname);
            for val = 1:20
                 fieldname = strcat('a',num2str(val));
                 hc(1) = state.(fieldname);
                 
            end
            
        end
       pause(DELAY);
    
    end
    
    
% Pushbutton callback. Here the joints have been selected
    function p_call(varargin)
     
    set(h.f,'visible','off');
    %resume the figure that shows the point light displays
    uiresume(gcbf);
     %load arrays with one if checked
   for val = 1:20
       if get(h.c(val),'Value')==1
           hc(val) = 1;
       end
   end
  
   %save the state of the joints
   saveState();
   
   %call the function that generates the point-light displays
   if(strcmp(stimuliType,'n')==1)
            funcplot(fname,joints,hc);
   elseif(strcmp(stimuliType,'r')==1)
           funcplotRandom(fname,joints,hc);
   else
       error('The stimuli type must be \"n\" or \"r\"');
   end

     
   % hold on;
    end
    
    %function that selects all the joints
    function selectAll(varargin)
    for i = 1:numel(h.c)
        set(h.c(i),'Value',1);
    end
    end

    %function that clears all the joints selected
    function clearAll(varargin)
        for i = 1:numel(h.c)
            set(h.c(i),'Value',0);
        end
    end
  
     function bselection(source,callbackdata)
       display(['Previous: ' callbackdata.OldValue.String]);
       display(['Current: ' callbackdata.NewValue.String]);
       display('------------------');
    end 
end
 

    








